'use client'

import { useState, useEffect, useRef } from 'react'
import { FiBell, FiSearch, FiUser, FiSun, FiMoon, FiMenu, FiX, FiCheck, FiVolume2, FiVolumeX } from 'react-icons/fi'
import { useTheme } from '@/contexts/ThemeContext'
import { useUser } from '@/contexts/UserContext'
import { useNotificationStore } from '@/store/useNotificationStore'
import { format } from 'date-fns'
import { tr } from 'date-fns/locale'

export default function Header({ setIsOpen }: { setIsOpen: (isOpen: boolean) => void }) {
  const [showNotifications, setShowNotifications] = useState(false)
  const notificationRef = useRef<HTMLDivElement>(null)
  const { isDark, toggleTheme } = useTheme()
  const { user } = useUser()
  const message = useNotificationStore((state) => state.message)
  const notifications = useNotificationStore((state) => state.notifications)
  const soundEnabled = useNotificationStore((state) => state.soundEnabled)
  const toggleSound = useNotificationStore((state) => state.toggleSound)
  const markAsRead = useNotificationStore((state) => state.markAsRead)
  const clearNotifications = useNotificationStore((state) => state.clearNotifications)

  // Bildirim panelini dışarı tıklandığında kapat
  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      if (notificationRef.current && !notificationRef.current.contains(event.target as Node)) {
        setShowNotifications(false)
      }
    }

    document.addEventListener('mousedown', handleClickOutside)
    return () => document.removeEventListener('mousedown', handleClickOutside)
  }, [])

  const unreadCount = notifications.filter(n => !n.read).length

  return (
    <header className="sticky top-0 w-full bg-white/95 dark:bg-slate-800/95 border-b border-slate-100 dark:border-slate-700/50 backdrop-blur-lg z-30">
      <div className="px-4 sm:px-6 py-3 sm:py-4">
        <div className="flex items-center justify-between gap-4">
          {/* Sol Taraf - Menü ve Arama */}
          <div className="flex items-center gap-4 flex-1 max-w-xl">
            <button
              onClick={() => setIsOpen(true)}
              className="block lg:hidden p-2 rounded-xl hover:bg-slate-100 dark:hover:bg-slate-700/50 transition-colors"
            >
              <FiMenu className="w-5 h-5 text-fuchsia-500" />
            </button>
          </div>

          {/* Sağ Taraf */}
          <div className="flex items-center gap-2 sm:gap-4">
            <button
              onClick={toggleTheme}
              className="p-2 rounded-xl hover:bg-slate-100 dark:hover:bg-slate-700/50 transition-colors"
            >
              {isDark ? (
                <FiSun className="w-5 h-5 sm:w-6 sm:h-6 text-slate-600 dark:text-slate-400" />
              ) : (
                <FiMoon className="w-5 h-5 sm:w-6 sm:h-6 text-slate-600 dark:text-slate-400" />
              )}
            </button>

            {/* Bildirimler */}
            <div className="relative" ref={notificationRef}>
              <button 
                onClick={() => setShowNotifications(!showNotifications)}
                className="relative p-2 rounded-xl hover:bg-slate-100 dark:hover:bg-slate-700/50 transition-colors"
              >
                <FiBell className="w-5 h-5 sm:w-6 sm:h-6 text-slate-600 dark:text-slate-400" />
                {unreadCount > 0 && (
                  <span className="absolute top-1.5 right-1.5 w-2 h-2 bg-red-500 rounded-full animate-pulse" />
                )}
              </button>

              {/* Bildirim Paneli */}
              {showNotifications && (
                <div className="absolute right-0 top-full mt-2 w-80 max-w-[90vw] bg-white/95 dark:bg-slate-800/95 
                                rounded-xl shadow-2xl border border-slate-200 dark:border-slate-700 z-[9999]
                                backdrop-blur-lg">
                  <div className="p-3 border-b border-slate-200 dark:border-slate-700 flex justify-between items-center">
                    <h3 className="font-semibold text-slate-900 dark:text-white">Bildirimler</h3>
                    <div className="flex items-center gap-2">
                      <button
                        onClick={toggleSound}
                        className="p-1.5 rounded-lg hover:bg-slate-100/80 dark:hover:bg-slate-700/80 text-slate-600 dark:text-slate-400"
                      >
                        {soundEnabled ? <FiVolume2 className="w-4 h-4" /> : <FiVolumeX className="w-4 h-4" />}
                      </button>
                      <button
                        onClick={clearNotifications}
                        className="p-1.5 rounded-lg hover:bg-slate-100/80 dark:hover:bg-slate-700/80 text-slate-600 dark:text-slate-400"
                      >
                        <FiX className="w-4 h-4" />
                      </button>
                    </div>
                  </div>
                  
                  <div className="max-h-[calc(100vh-200px)] overflow-y-auto">
                    {notifications.length === 0 ? (
                      <div className="py-12 text-center text-slate-500 dark:text-slate-400">
                        <FiBell className="w-8 h-8 mx-auto mb-3 opacity-50" />
                        <p>Henüz bildirim bulunmuyor</p>
                      </div>
                    ) : (
                      notifications.map((notification) => (
                        <div 
                          key={notification.id}
                          className={`p-3 border-b border-slate-200 dark:border-slate-700 last:border-0
                                    hover:bg-slate-100/80 dark:hover:bg-slate-700/80 transition-colors cursor-pointer
                                    ${notification.read ? 'opacity-75' : ''}`}
                          onClick={() => markAsRead(notification.id)}
                        >
                          <div className="flex items-start gap-3">
                            <div className={`mt-1.5 w-2 h-2 rounded-full flex-shrink-0
                                          ${notification.type === 'waiter' ? 'bg-purple-500' : 'bg-blue-500'}`} />
                            <div className="flex-1 min-w-0">
                              <p className="text-sm text-slate-900 dark:text-white font-medium">
                                {notification.message}
                              </p>
                              <p className="text-xs text-slate-500 dark:text-slate-400 mt-1">
                                {format(notification.timestamp, 'dd MMM HH:mm', { locale: tr })}
                              </p>
                            </div>
                            {!notification.read && (
                              <button 
                                onClick={(e) => {
                                  e.stopPropagation()
                                  markAsRead(notification.id)
                                }}
                                className="p-1 hover:bg-slate-200/80 dark:hover:bg-slate-600/80 rounded-lg"
                              >
                                <FiCheck className="w-4 h-4 text-green-500" />
                              </button>
                            )}
                          </div>
                        </div>
                      ))
                    )}
                  </div>
                </div>
              )}
            </div>

            {/* Profil */}
            <div className="flex items-center gap-2 sm:gap-3">
              <div className="w-8 h-8 sm:w-10 sm:h-10 rounded-xl bg-gradient-to-br from-fuchsia-500 to-purple-500 flex items-center justify-center text-white">
                <FiUser className="w-4 h-4 sm:w-5 sm:h-5" />
              </div>
              <div className="hidden md:block">
                <p className="text-sm font-medium text-slate-700 dark:text-slate-200">
                  {user?.name || 'Misafir Kullanıcı'}
                </p>
                <p className="text-xs text-slate-500 dark:text-slate-400">
                  {user?.email || 'Giriş yapılmadı'}
                </p>
              </div>
            </div>
          </div>
        </div>
      </div>
    </header>
  )
} 